summaryrefslogtreecommitdiffstats
path: root/kicker/applets/systemtray/systemtrayapplet.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kicker/applets/systemtray/systemtrayapplet.cpp')
-rw-r--r--kicker/applets/systemtray/systemtrayapplet.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kicker/applets/systemtray/systemtrayapplet.cpp b/kicker/applets/systemtray/systemtrayapplet.cpp
index 0175bd689..ed138212f 100644
--- a/kicker/applets/systemtray/systemtrayapplet.cpp
+++ b/kicker/applets/systemtray/systemtrayapplet.cpp
@@ -110,7 +110,7 @@ SystemTrayApplet::SystemTrayApplet(const TQString& configFile, Type type, int ac
setBackgroundOrigin(AncestorOrigin);
- twin_module = new KWinModule(this);
+ twin_module = new TWinModule(this);
// tdeApp notifies us of settings changes. added to support
// disabling of frame effect on mouse hover
@@ -156,7 +156,7 @@ void SystemTrayApplet::initialize()
layoutTray();
}
// the KWinModule notifies us when tray windows are added or removed
connect( twin_module, TQ_SIGNAL( systemTrayWindowAdded(WId) ),
this, TQ_SLOT( systemTrayWindowAdded(WId) ) );
connect( twin_module, TQ_SIGNAL( systemTrayWindowRemoved(WId) ),
@@ -156,7 +156,7 @@ void SystemTrayApplet::initialize()
layoutTray();
}
- // the KWinModule notifies us when tray windows are added or removed
+ // the TWinModule notifies us when tray windows are added or removed
connect( twin_module, TQ_SIGNAL( systemTrayWindowAdded(WId) ),
this, TQ_SLOT( systemTrayWindowAdded(WId) ) );